import builtins

class Meringue(list):
    def last(self):
        return self.at(-1)
        
    def unique(self):
        print(self)
        return Meringue([i for n, i in enumerate(self) if i not in self[:n]])
        
    def removeAllInstances(self, *items):
        temp = self
        for item in items:
            temp = filter(lambda i : i != item, temp)
        return Meringue(temp)
        
    def removeCommonElements(self, *lists):
        _list = self.flat(lists)
        return Meringue(filter(lambda i : i not in _list, self))
            
    def flat(self, _list):
        if not _list:
            _list = self
        temp = []
        for item in _list:
            if isinstance(item, (list, tuple)):
                for subitem in item: 
                    temp.append(subitem)
            else:
                temp.append(item)
        return Meringue(temp)
        
    def at(self, n=0):
        return self[n]

builtins.Meringue = Meringue


import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="pymeringue",
    version="1.0.0",
    description="A port of Meringue (https://github.com/stiive/meringue) for Python.",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/stiive/py-meringue",
    author="Beckett Normington",
    author_email="beckett@chatter-social.com",
    license="BSD",
    classifiers=[
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
    ],
    packages=["meringue"]
)